<div class="chatlog__dropdown-content">
	<a href="#">
		<div class="chatlog__dropdown-emoji">
			<span class="dropdownContentEmoji">{{EMOJI}}</span>
		</div>
		<div class="chatlog__dropdown-text">
			<span class="dropdownContentTitle">{{TITLE}}</span>
			<br>
			<span class="dropdownContentDesc">{{DESCRIPTION}}</span>
		</div>
	</a>
</div>