<div class="chatlog__followup">
	<img class="chatlog__followup-avatar" src="{{AVATAR_URL}}" alt="Avatar" loading="lazy" data-user-id="{{USER_ID}}">
	{{BOT_TAG}}
	<div class="chatlog__followup-author" style="{{USER_COLOUR}}" data-user-id="{{USER_ID}}">{{NAME}}</div>
	<div class="chatlog__followup-content">
		<span class="chatlog__reference-link" onclick="scrollToMessage(event, '{{MESSAGE_ID}}')">
			{{CONTENT}} {{ICON}}
		</span>
		{{EDIT}}
	</div>
</div>