<div class="chatlog__followup">
        <img class="chatlog__followup-avatar" src="{{AVATAR_URL}}" alt="Avatar" loading="lazy" data-user-id="{{USER_ID}}">
        {{BOT_TAG}}
        <div class="chatlog__followup-author" style="{{USER_COLOUR}}" data-user-id="{{USER_ID}}">{{NAME}}</div>
        <div class="chatlog__followup-content">
            <span class="chatlog__interaction-filler">{{FILLER}}</span>
            <span class="chatlog__interaction-link">{{COMMAND}}</span>
        </div>
</div>