<div class="chatlog__message-group">
    <div id="chatlog__message-container-{{MESSAGE_ID}}" class="chatlog__message-container" data-message-id="{{MESSAGE_ID}}">
        <div class="chatlog__message">
            <div class="chatlog__message-aside">
               <img class="chatlog__pin-avatar" src="{{THREAD_URL}}" />
            </div>
            <div class="chatlog__message-primary">
                <div class="chatlog__header">
                </div>

                <div class="chatlog__content chatlog__markdown" data-message-id="{{MESSAGE_ID}}" id="message-{{MESSAGE_ID}}">
                    <span class="chatlog__reference-name" title="{{NAME_TAG}}" style="{{USER_COLOUR}}">{{NAME}}</span> removed
                    <span class="chatlog__reference-name" title="{{RECIPIENT_NAME_TAG}}" style="{{RECIPIENT_USER_COLOUR}}">{{RECIPIENT_NAME}}</span> from the thread.
                </div>
            </div>
        </div>
    </div>
</div>