        <div id="chatlog__message-container-{{MESSAGE_ID}}" class="chatlog__message-container" data-message-id="{{MESSAGE_ID}}">
                <div class="chatlog__message">
                    <div class="chatlog__message-aside">
                        <div class="chatlog__short-timestamp" data-timestamp="{{TIMESTAMP}}">{{TIME}}</div>
                    </div>
                    <div class="chatlog__message-primary">
                        <div class="chatlog__content chatlog__markdown" data-message-id="{{MESSAGE_ID}}" id="message-{{MESSAGE_ID}}">
                            {{MESSAGE_CONTENT}}

                            {{ATTACHMENTS}}

                            {{EMBEDS}}

                            {{COMPONENTS}}

                            {{EMOJI}}

                        </div>
                    </div>
                </div>
        </div>